Page 119 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 119

Home

    Garrido Canabal, who under Calles planned and
    carried out such conscience killing devices, had been
    sent to Russia to study the Soviet education system.

    Under Calles 90 percent of the churches, and all
    Catholic schools and convents were confiscated and

    closed. Only twenty-five priests were allowed to minister
    to the 1,700,000 people in the Federal District. Priests
    were banned from fourteen states, many being tortured
    and slain. All bishops were listed for expulsion and

    death.

    Typical of Socialist regimes, every excuse was used
    to confiscate private property, even homes where church
    services were held, or priests were hidden. Rewards
    were offered to those who would report such "criminal

    people was being shed. The savagery against those who
    protested v was such that on one occasion hundreds of

    aad 1 a4 a el

    women and children lay wounded or dying in the streets.
    When 10,000 students and 60,000 parents marched in

    protest to Calles' educational program, the United States

    Ambassador, Josephus Daniels, came to his aid with

    man."

    When the Mexican people rose up in arms against
    sacrilege, rape and rapine (the Cristero period 1926-
    1929) and Calles forces were in danger of being
    overthrown, American combat planes were sent to drop

    114

    The Secret Side of History

    amendments were posted in Congress demanding their

    offenses."

    Through all of this, the blood of a gentle and devout

    American support and eulogies to "Mexico's strong